import * as z from 'zod';
import { Action } from './clients/dispatcher/action-listener';
import { LogLevel } from './clients/event/event-client';
import { Logger } from './util/logger';
import { HatchetClient } from './clients/hatchet-client';
import { RunEventType } from './clients/listener/listener-client';
export declare const CreateStepSchema: z.ZodObject<{
    name: z.ZodString;
    parents: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    timeout: z.ZodOptional<z.ZodString>;
    retries: z.ZodOptional<z.ZodNumber>;
}, "strip", z.ZodTypeAny, {
    name: string;
    parents?: string[] | undefined;
    timeout?: string | undefined;
    retries?: number | undefined;
}, {
    name: string;
    parents?: string[] | undefined;
    timeout?: string | undefined;
    retries?: number | undefined;
}>;
type JSONPrimitive = string | number | boolean | null | Array<JSONPrimitive>;
export type NextStep = {
    [key: string]: NextStep | JSONPrimitive | Array<NextStep>;
};
interface ContextData<T, K> {
    input: T;
    parents: Record<string, any>;
    triggered_by: string;
    user_data: K;
}
declare class ChildWorkflowRef<T> {
    workflowRunId: Promise<string>;
    client: HatchetClient;
    constructor(workflowRunId: Promise<string>, client: HatchetClient);
    stream(): Promise<AsyncGenerator<{
        type: RunEventType;
        payload: string;
    }, void, unknown>>;
    result(): Promise<T>;
    toJSON(): Promise<string>;
}
export declare class Context<T, K> {
    data: ContextData<T, K>;
    input: T;
    controller: AbortController;
    action: Action;
    client: HatchetClient;
    overridesData: Record<string, any>;
    logger: Logger;
    spawnIndex: number;
    constructor(action: Action, client: HatchetClient);
    stepOutput(step: string): NextStep;
    triggeredByEvent(): boolean;
    workflowInput(): T;
    userData(): K;
    stepName(): string;
    workflowRunId(): string;
    playground(name: string, defaultValue?: string): string;
    log(message: string, level?: LogLevel): void;
    spawnWorkflow<P = unknown>(workflowName: string, input: T, key?: string): ChildWorkflowRef<P>;
}
export type StepRunFunction<T, K> = (ctx: Context<T, K>) => Promise<NextStep> | NextStep | void;
export interface CreateStep<T, K> extends z.infer<typeof CreateStepSchema> {
    run: StepRunFunction<T, K>;
}
export {};
